@@ -95,7 +95,7 @@ class SpatialAnalysis:
           locator = Nominatim(user_agent='myGeocoder')
           for i in range (0, len(self.c)):
               if (i % 100 == 0):
-                print(str(i)+'th', 'Address being searched for now.')
+                  print(str(i)+'th', 'Address being searched for now.')
               location = locator.geocode(self.c[self.__AddressColumnName][i], timeout=10000)
               if location is not None:
                   self.c.loc[i, 'Latitude'] = location.latitude
@@ -256,7 +256,7 @@ class SpatialAnalysis:
   # EFFECT: Deletes column from the .csv file that the user inputed to the SpatialAnalysis
   # NOTE1: INTENDED USE IS TO UNDO CHANGES FOR TUTORIAL
   def destroy_mods(self):
-      assert(input('This function will destroy additions to the .csv file. Enter 1 to confirm or any input to cancel: ') != '1')
+      assert(input('This function will destroy additions to the .csv file. Enter 1 to confirm or any input to cancel: ') == '1')
       del self.c['Is Outlier']
       del self.c['Region']
       del self.c['Distance from Stadium (miles)']
@@ -264,12 +264,40 @@ class SpatialAnalysis:
       del self.c['Longitude']
       self.c.to_csv(self.__path, index=False)
 
-  # REQUUIRES: valid csv input
-  # MODIFIES: N/A
-  # EFFECT: if used in Colab / Jupyter a visual of the data will print
-  def printCSV(self):
-      print('if used in Colab / Jupyter a visual of the data will print')
-      self.c
+  # REQUUIRES: N/A
+  # MODIFIES: self.c
+  # EFFECT: does the same as initalization for SLD with harversine but user prompted
+  # PURPOSE: To allow the user to maually enter lat and long values for GeoPy fetch fails
+        # and update the .csv without reruning the enter SLDneed=True version of the
+        # constructor
+  def manualLatLong(self):
+    for i in range(0, len(self.c)):
+        if self.c['Latitude'][i] is not None and self.c['Longitude'] is not None:
+            geoAdd = (float(self.c['Latitude'][i]), float(self.c['Longitude'][i]))
+            self.c.loc[i, 'Distance from Stadium (miles)'] = hs.haversine(self.__centCords, geoAdd, unit=Unit.MILES)
+            self.c.to_csv(self.__path, index=False)
+            if self.c['Latitude'][i] > self.__LatPark and self.c['Longitude'][i] > self.__LongPark:
+                self.c.at[i, 'Region'] = 'NE'
+            elif self.c['Latitude'][i] > self.__LatPark and self.c['Longitude'][i] < self.__LongPark:
+                self.c.at[i, 'Region'] = 'NW'
+            elif self.c['Latitude'][i] < self.__LatPark and self.c['Longitude'][i] < self.__LongPark:
+                self.c.at[i, 'Region'] = 'SW'
+            elif self.c['Latitude'][i] < self.__LatPark and self.c['Longitude'][i] > self.__LongPark:
+                self.c.at[i, 'Region'] = 'SE'
+            else:
+                self.c.at[i, 'Region'] = np.nan
+    self.c.to_csv(self.__path, index=False)
+    for i in range(0, len(self.c)):
+        if self.c['Distance from Stadium (miles)'][i] > self.__radSize or self.c['Distance from Stadium (miles)'][i] == 0:
+            self.c['Distance from Stadium (miles)'][i] = np.nan
+            self.c['Region'][i] = np.nan
+            self.c['Latitude'][i] = np.nan
+            self.c['Longitude'][i] = np.nan
+            self.c['Is Outlier'][i] = np.nan
+        print('NUM ERRORS=', self.c['Distance from Stadium (miles)'].isna().sum(), 'Values.')
+        if (self.c['Distance from Stadium (miles)'].isna().sum() != 0):
+            print('Either manual entry of latitude and longitude was incomplete in some way, or some data should NOT have been included in the set.')
+    self.c.to_csv(self.__path, index=False)
     
   # REQUIRES: numeric input
   # MODIFIES: print / matplotlib output
@@ -304,10 +332,6 @@ class SpatialAnalysis:
           plt.ylabel('Average Value (USD$ may be rounded to 6 decimals)')
 
 
-        
-      
-
-
   ####################################################################################################################################
   #################################################### FULL AREA GRAPHING FUNCTIONS ##################################################
   ####################################################################################################################################
